pub struct SerializableFstDict {
pub values: Vec<Vec<Delta>>,
pub max_key_length: u32,
}Fields
values: Vec<Vec<Delta>>max_key_length: u32Trait Implementations
Sourceimpl Archive for SerializableFstDict
impl Archive for SerializableFstDict
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSerializableFstDict
type Archived = ArchivedSerializableFstDict
The archived representation of this type. Read more
Sourcetype Resolver = SerializableFstDictResolver
type Resolver = SerializableFstDictResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for SerializableFstDict
impl Debug for SerializableFstDict
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SerializableFstDict, __D> for Archived<SerializableFstDict>
impl<__D: Fallible + ?Sized> Deserialize<SerializableFstDict, __D> for Archived<SerializableFstDict>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SerializableFstDict, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SerializableFstDict, <__D as Fallible>::Error>
Deserializes using the given deserializer